# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from deep_agent_sdk.models.wrapped_response_tools_catalog_response import WrappedResponseToolsCatalogResponse  # noqa: E501

class TestWrappedResponseToolsCatalogResponse(unittest.TestCase):
    """WrappedResponseToolsCatalogResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseToolsCatalogResponse:
        """Test WrappedResponseToolsCatalogResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseToolsCatalogResponse`
        """
        model = WrappedResponseToolsCatalogResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseToolsCatalogResponse(
                done = True,
                result = deep_agent_sdk.models.tools_catalog_response.ToolsCatalogResponse(
                    tools = [
                        deep_agent_sdk.models.catalog_tool_entry.CatalogToolEntry(
                            key = '', 
                            default_enabled = True, 
                            is_essential = True, )
                        ], )
            )
        else:
            return WrappedResponseToolsCatalogResponse(
                result = deep_agent_sdk.models.tools_catalog_response.ToolsCatalogResponse(
                    tools = [
                        deep_agent_sdk.models.catalog_tool_entry.CatalogToolEntry(
                            key = '', 
                            default_enabled = True, 
                            is_essential = True, )
                        ], ),
        )
        """

    def testWrappedResponseToolsCatalogResponse(self):
        """Test WrappedResponseToolsCatalogResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt

class RunChatContext(BaseModel):
    """
    Chat context for run creation.  # noqa: E501
    """
    id: StrictInt = Field(default=..., description="Chat ID (used internally as checkpointer thread_id)")
    chat_session_id: StrictInt = Field(default=..., description="Chat session ID (one exchange)")
    bot_chat_member_id: StrictInt = Field(default=..., description="Bot chat member ID")
    __properties = ["id", "chat_session_id", "bot_chat_member_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RunChatContext:
        """Create an instance of RunChatContext from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RunChatContext:
        """Create an instance of RunChatContext from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RunChatContext.parse_obj(obj)

        _obj = RunChatContext.parse_obj({
            "id": obj.get("id"),
            "chat_session_id": obj.get("chat_session_id"),
            "bot_chat_member_id": obj.get("bot_chat_member_id")
        })
        return _obj


